%
% Natural Science Review journal document class file
% v0.1 for LaTeX 2e
%
% Copyright (C) 2024 Natural Science Review
%
% This file may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3c
% of this license or (at your option) any later version.
%
%%Identification

\def\@version{1.1}
\def\filedate{2024/08/24}
\def\docdate {2024/08/24}   % Today

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{nsr}[\filedate\space v\@version\space LaTeX2e NSR document class from\space\docdate] \relax

\typeout{------------------------------------------------------------------------}
\typeout{LaTeX2e Class file for Natural Science Review publication for LaTeX2e users}
\typeout{ }
\typeout{Use the boxit option to draw a box on page showing the correct margins}
\typeout{ }
\typeout{Itemize, Enumerate and Description environments are compact versions}
\typeout{------------------------------------------------------------------------}
\typeout{ }

%%Preliminary definitions, needed by the options
\providecommand{\headlinecolor}{\normalcolor}   % define initial headline color

\RequirePackage{xcolor}                     % setup color see scheme at https://encycolorpedia.ru/1761ab
\definecolor{slcolor}{HTML}{882B21}
\definecolor{electric}{HTML}{4169e1}

%%This parts handles the options passed to the class.

%\newif\ifnsrbiblatex
\newif\ifnsrrefpage
\newif\iftwocolumnpaper

\DeclareOption{authoryear}{\xdef\@biboptions{round,authoryear}}
\DeclareOption{number}{\xdef\@biboptions{numbers}}
\DeclareOption{numbers}{\xdef\@biboptions{numbers}}

\typeout{------------------------------------------------------------------------}    
\typeout{Latex Class Setting:}

\DeclareOption{a5paper}{%
    \PassOptionsToPackage{paper=a5paper}{geometry}
    \typeout{Setup for A5 PAPER}
    }    

\DeclareOption{usletterpaper}{%
   \PassOptionsToPackage{paper=letterpaper}{geometry}
   \typeout{*Setup for US LETTER PAPER}
   }

\DeclareOption{boxit}{%
    \PassOptionsToPackage{showframe}{geometry}    
    \typeout{*SHOW margins frame}    
     }

\DeclareOption{a4paper}{%
    \PassOptionsToPackage{paper=a4paper}{geometry}
    \typeout{*Setup for A4 PAPER}    
    }    

\DeclareOption{twocolumn}{%
    \PassOptionsToClass{twocolumn}{article}
    \PassOptionsToClass{12pt}{article}
    \@twocolumntrue    
    \typeout{*TWO column PAPER}
    }

\DeclareOption{onecolumn}{%
    \PassOptionsToClass{onecolumn}{article}
    \PassOptionsToClass{12pt}{article}
    \@twocolumnfalse       
    \typeout{*ONE column PAPER}    
    }

%\DeclareOption{biblatex}{\nsrbiblatextrue}

\DeclareOption{refpage}{\nsrrefpagetrue}

\typeout{------------------------------------------------------------------------}    

%\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}

\ExecuteOptions{a4paper}
\ProcessOptions

\DeclareOption{onecolumn}{\OptionNotUsed}
%\DeclareOption{red}{\renewcommand{\headlinecolor}{\color{slcolor}}}
%\DeclareOption{green}{\renewcommand{\headlinecolor}{\color{green}}}
%\DeclareOption{blue}{\renewcommand{\headlinecolor}{\color{electric}}}
\DeclareOption{black}{\renewcommand{\headlinecolor}{\color{black}}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}
\RequirePackage[]{flushend} %% modified 2.5

%% The amsmath package provides various useful equation environments.
\RequirePackage{amsmath}

%% The amssymb package provides various useful mathematical symbols.
\RequirePackage{amssymb}

%
% Page layout:
%
\RequirePackage[%		
		columnsep  	= 5mm,
		left        = 20mm,
		bottom      = 56pt,
		paperwidth 	= 595bp,  %% paperwidth   597.23 pt = 595.0 bp  {597.22530 pt]
		textwidth  	= 170mm,
		paperheight = 792bp,  %% paperheight  794.97 pt ≅ 792.0 bp  [794.96208 pt]
		textheight  = 9.5in,
		nomarginpar,
%		heightrounded,
%		noheadfoot,
		centering,
        headheight=33pt,
        headsep=20pt,
        footskip=25pt,
        footnotesep=24pt plus 2pt minus 12pt
        ]
		{geometry}

\columnseprule 0pt
\usepackage[hang]{footmisc}
\setlength{\footnotemargin}{.6em}

\RequirePackage{url}

%%% Изображения %%%
\RequirePackage{graphicx}[2014/04/25]            % Подключаем пакет работы с графикой
\graphicspath{{figures/}}    % Пути к изображениям

%%% Fonts %%%
\RequirePackage[T1,T2A]{fontenc}                    % Поддержка русских букв
\RequirePackage[utf8]{inputenc}[2014/04/30]         % Кодировка utf8
% \RequirePackage[english, russian]{babel}[2014/03/24]% Языки: русский, английский
\RequirePackage[english]{babel}[2014/03/24]% Языки: английский
\RequirePackage{indentfirst}                        % Красная строка
\RequirePackage{multicol}
%Посмотреть размеры документа, в тексте ещё команда
\RequirePackage{layout}

\RequirePackage{lineno}


%\RequirePackage[backend=biber]{biblatex}
%\addbibresource{sample.bib}
%\RequirePackage{csquotes}

%\RequirePackage{pscyr}

\RequirePackage{blindtext}

\RequirePackage{booktabs}
\RequirePackage[figureposition=bottom,tableposition=top,skip=10pt, font=small, labelsep=period, labelfont=bf]{caption}

%\RequirePackage{authblk}
\RequirePackage[affil-sl]{authblk}
\renewcommand{\Affilfont}{\small\itshape}

\RequirePackage[unicode=true,
	bookmarksopen={true},
	pdffitwindow=true, 
	colorlinks=true, 
	linkcolor=blue, 
	citecolor=blue, 
	urlcolor=blue, 
	hyperfootnotes=false, 
	pdfstartview={FitH},
	pdfpagemode= UseNone]{hyperref}

\RequirePackage{orcidlink}

%\newcommand{\hreflink}[1]{\gdef\@hreflink{#1}}

%%Body of the class, most of the declarations appear here.

%Lists

\RequirePackage{enumitem}
\newenvironment{Enumerate}{\begin{enumerate}[nosep]}{\end{enumerate}}
\newenvironment{Itemize}{\begin{itemize}[nosep]}{\end{itemize}}
\newenvironment{Description}{\begin{description}[nosep]}{\end{description}}

%Floatparameter:
\renewcommand{\topfraction}{.95}
\renewcommand{\bottomfraction}{.95}
\renewcommand{\textfraction}{0.1}
\renewcommand{\floatpagefraction}{0.8}


%Bibtex
\@ifundefined{@biboptions}{\xdef\@biboptions{numbers,sort&compress}}{}
\InputIfFileExists{\jobname.spl}{}{}
\RequirePackage[\@biboptions]{natbib}

\newwrite\splwrite
\immediate\openout\splwrite=\jobname.spl
\def\biboptions#1{\def\next{#1}\immediate\write\splwrite{%
   \string\g@addto@macro\string\@biboptions{%
    ,\expandafter\strip@prefix\meaning\next}}}

 \global\let\bibfont=\small
 \global\bibsep=1pt


\@ifpackageloaded{amsrefs}%
  {}
  {%\let\bibsection\relax%
  \AtBeginDocument{\def\cites@b#1#2,#3{%
    \begingroup[%
        \toks@{\InnerCite{#2}#1}%
        \ifx\@empty#3\@xp\@gobble\fi
        \cites@c#3%
}}}

\def\@seccntDot{.}
\def\@seccntformat#1{\csname the#1\endcsname\@seccntDot\hskip 0.5em}

\renewcommand\section{\@startsection {section}{1}{\z@}%
           {12\p@ \@plus 6\p@ \@minus 3\p@}%
           {12\p@ \@plus 6\p@ \@minus 3\p@}%
           {\normalsize\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
           {10\p@ \@plus 6\p@ \@minus 3\p@}%
           {10\p@ \@plus 6\p@ \@minus 3\p@}%
           {\normalfont\normalsize\itshape}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
           {6\p@ \@plus 6\p@ \@minus 3\p@}%
           {6\p@ \@plus 6\p@ \@minus 3\p@}%
           {\normalfont\normalsize\itshape}}

\newlength{\titleblockheight}       % so user can change it if need be
\setlength{\titleblockheight}{3.5cm}

\newlength\titleblockstartskip
\setlength\titleblockstartskip{100pt}

\newlength\titleblockmiddleskip
\setlength\titleblockmiddleskip{1em}

\newlength\titleblockendskip
\setlength\titleblockendskip{1em}

\AtEndDocument{\label{lastpage}}

\def\volume#1{\gdef\@vol{#1}}
\def\firstpage#1{\gdef\@firstpage{#1}%
                  \setcounter{page}{#1}}
                  
\def\lastpage{\pageref*{lastpage}}

\def\runauth#1{\gdef\@runauth{#1}}
%\runauth{Author}

\def\@datereceived{}
\newcommand{\datereceived}[1]{\gdef\@datereceived{#1}} 
\def\@daterevised{}
\newcommand{\daterevised}[1]{\gdef\@daterevised{#1}} 
\def\@dateaccepted{}
\newcommand{\dateaccepted}[1]{\gdef\@dateaccepted{#1}} 
\def\@datepublished{}
\newcommand{\datepublished}[1]{\gdef\@datepublished{#1}} 
\def\@doinum{}
\newcommand{\doinum}[1]{\gdef\@doinum{#1}}
\def\@copyrightyear{}
\newcommand{\copyrightyear}[1]{\gdef\@copyrightyear{#1}}


\RequirePackage{fancyhdr}

\fancypagestyle{plain}{%
		\fancyhf{}
        \renewcommand*\headrulewidth{0pt}
        \setlength{\topmargin}{-50pt}

    \fancyhead[C]{
        \parbox{0.65\textwidth}{\centering\normalsize{%
         {NATURAL SCIENCE REVIEW}~{\bfseries\@vol}~(\the\year)~%
            \@firstpage--\lastpage}}
            \vspace{2pt}
            \hrule height 2pt 
            \vspace{2pt}

        \parbox{0.6\textwidth}{\centering\normalsize{%{journal homepage: }%
        \href{https://nsr.jinr.int}{\color{black}{nsr.jinr.int}}}}
        }
        
        \fancyfoot[L]{\vspace{-70pt}\\
            \footnotesize\href{https://doi.org/\@doinum}{\color{black}{https://doi.org/\@doinum}}\\            
            \footnotesize{Received: \@datereceived;
            Revised: \@daterevised\\
            Accepted: \@dateaccepted;
            Published: \@datepublished\\}
            \footnotesize{© }\@copyrightyear{ Natural Science Review}
        }}

\def\@maketitle{%
                \vspace*{-80pt}
                \vskip \titleblockstartskip \centering    
                {\Large\bfseries\headlinecolor {\@title} \par}
                \vskip \titleblockmiddleskip               % Vertical space after title
                {\begin{tabular}[t]{@{}c@{}}\normalsize\@author \end{tabular}\par}
                \vskip \titleblockendskip                 % Vertical space after author       
                \enlargethispage{-4\baselineskip}
                }


\renewenvironment{abstract}{%
    \hrule
    \if@twocolumn           
        \section*{\abstractname}%                  
        \small \begin{center}%
        {\bfseries \abstractname\vspace{-.5em}\vspace{\z@}}%
        \end{center}%
        \quotation
    \else
        \vspace{0pt}
        \small \begin{flushleft}%
        \bfseries \abstractname \vspace{-.5em}\vspace{\z@}%
        \end{flushleft}
    \fi \par
     }


\def\keyword{%
  \vspace{5pt}
  \small \parskip\z@
  \noindent\textit{Keywords: }
  \raggedright                         
  \ignorespaces}
\def\endkeyword{\vspace{5pt} \par }

\def\pacs{%
  \small \parskip\z@
  \noindent{PACS numbers: }
  \raggedright                        
  \ignorespaces}
\def\endpacs{\vspace{10pt} \hrule \vspace{8pt} \par }

\RequirePackage[normalem]{ulem}

\def\ps@headings{%
    \def\@oddhead{\uline{\parbox{0.5\textwidth}{\itshape\footnotesize\@runauth}%
    \parbox{0.5\textwidth}{\raggedleft\itshape\footnotesize%
    {Natural Science Review}~\@vol~(\the\year)~%
         \@firstpage--\lastpage%
         }}}%
    \let\@evenhead\@oddhead
    \let\@evenfoot\@empty%
    \let\@evenfoot\@oddfoot
    }


\pagestyle{headings}


\def\@alph#1{%
  \ifcase#1\or a\or b\or c\or d\or e\or f\or g\or h\or i\or j\or k\or
  l\or m\or n\or o\or p\or q\or r\or s\or t\or u\or v\or w\or x\or
  y\or z%
  \or aa\or ab\or ac\or ad\or ae\or af\or ag\or ah\or ai\or aj\or
  ak\or al\or am\or an\or ao\or ap\or aq\or ar\or as\or at\or au\or
  av\or aw\or ax\or ay\or az%
  \or ba\or bb\or bc\or bd\or be\or bf\or bg\or bh\or bi\or bj\or
  bk\or bl\or bm\or bn\or bo\or bp\or bq\or br\or bs\or bt\or bu\or
  bv\or bw\or bx\or by\or bz%
  \or ca\or cb\or cc\or cd\or ce\or cf\or cg\or ch\or ci\or cj\or
  ck\or cl\or cm\or cn\or co\or cp\or cq\or cr\or cs\or ct\or cu\or
  cv\or cw\or cx\or cy\or cz%
  \or da\or db\or dc\or dd\or de\or df\or dg\or dh\or di\or dj\or
  dk\or dl\or dm\or dn\or do\or dp\or dq\or dr\or ds\or dt\or du\or
  dv\or dw\or dx\or dy\or dz%
  \or ea\or eb\or ec\or ed\or ee\or ef\or eg\or eh\or ei\or ej\or
  ek\or el\or em\or en\or eo\or ep\or eq\or er\or es\or et\or eu\or
  ev\or ew\or ex\or ey\or ez%
  \or fa\or fb\or fc\or fd\or fe\or ff\or fg\or fh\or fi\or fj\or
  fk\or fl\or fm\or fn\or fo\or fp\or fq\or fr\or fs\or ft\or fu\or
  fv\or fw\or fx\or fy\or fz%
  \or ga\or gb\or gc\or gd\or ge\or gf\or gg\or gh\or gi\or gj\or
  gk\or gl\or gm\or gn\or go\or gp\or gq\or gr\or gs\or gt\or gu\or
  gv\or gw\or gx\or gy\or gz%
  \else\@ctrerr\fi}

\def\appendixname{Appendix }
\renewcommand\appendix{\par
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \setcounter{equation}{0}
  \@addtoreset{figure}{section}%
  \@addtoreset{table}{section}%
  \gdef\thefigure{\@Alph\c@section.\arabic{figure}}%
  \gdef\thetable{\@Alph\c@section.\arabic{table}}%
  \gdef\thesection{\appendixname~\@Alph\c@section}%
  \@addtoreset{equation}{section}%
  \gdef\theequation{\@Alph\c@section.\arabic{equation}}%
  \addtocontents{toc}{\string\let\string\numberline\string\tmptocnumberline}{}{}
}

% \number line width calculation for appendix.
\newdimen\appnamewidth
\def\tmptocnumberline#1{%
   \setbox0=\hbox{\appendixname}
   \appnamewidth=\wd0
   \addtolength\appnamewidth{2.5pc}
   \hb@xt@\appnamewidth{#1\hfill}
}

\RequirePackage{tocloft}
%\setlength{\cftsecnumwidth}{10pt}
\renewcommand{\tocloftpagestyle}{\ps@headings}
\renewcommand{\cfttoctitlefont}{\normalsize\bfseries}
\setlength\cftaftertoctitleskip{12pt}
\setlength{\cftbeforesecskip}{2pt}
\renewcommand{\cftsecfont}{\normalsize} 
\renewcommand{\cftsecaftersnum}{.}
\renewcommand{\cftsecleader}{\cftdotfill{\cftdotsep}}
\renewcommand{\cftsecpagefont}{\mdseries}

%table font small
\RequirePackage{etoolbox}
\AtBeginEnvironment{tabular}{\small}
